@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Exporter 'import';
 
@@ -202,8 +202,6 @@ JSON::WebToken - JSON Web Token (JWT) implementation
 
 JSON::WebToken is JSON Web Token (JWT) implementation for Perl
 
-SEE ALSO L<< http://tools.ietf.org/html/draft-ietf-oauth-json-web-token-00 >>
-
 B<< THIS MODULE IS ALPHA LEVEL INTERFACE. >>
 
 =head1 METHODS
@@ -292,4 +290,6 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
+L<< http://tools.ietf.org/html/draft-ietf-oauth-json-web-token >>
+
 =cut
